function dVdh = perturbacionodefile(h, V, flag, F, G, problema)
%perturbacionodefile
%   dVdh = perturbacionodefile(h, V, flag, F, G, problema)
%
%   Derivada del factor, intensidades y valores ante la perturbación.
%      h          punto de integración
%      V          variables V = [k; X'; Y]
%      flag       parámetro sin uso incluido para compatibilidad con Matlab
%      F          procesos de producción
%      G          perturbación
%      problema   para autovalores 0, para VN 1, y para TE 2
%      dVdh       derivada de las variables dVdh = [dkdh; dXdh'; dYdh]
%
%   Se usa la sintaxis de Matlab; véase help odefile. El parámetro flag 
%   está incluido para garantizar la compatibilidad con Matlab y puede 
%   definirse como []. Véase también perturbacionode.m

%Necesita perturbacion.m 

[filas, columnas, ancho] = size(F);                             %determina el tamaño del problema
k = V(1);                                                       %extrae k
X = V(2:filas+1)';                                              %extrae X
Y = V(filas+2:filas+columnas+1);                                %extrae Y
[sk, sX, sY] = perturbacion(F + h.*G, G, k, X, Y, problema, 1); %calcula las series para el grado 1
dVdh = [sk(1); sX(:,1); sY(:,1)];                               %extrae dkdh, dXdh, dYdh y las almacena